@@ -10,6 +10,7 @@
 #include "EventEditDialog.h"
 #include "TodoEditDialog.h"
 #include "JournalEditDialog.h"
+#include "BirthdayEditDialog.h"
 
 #include "ChangeClient.h"
 
@@ -19,6 +20,9 @@
 Version ChangeManager::m_version = 1;
 QDate ChangeManager::m_date = QDate::currentDate();
 
+bool ChangeManager::birthdayCalendarEnabled = false;
+BirthdayCalendar* ChangeManager::birthdayCalendar = NULL;
+
 ChangeClient* ChangeManager::activeClient = NULL;
 QTimer* ChangeManager::dateCheckTimer;
 
@@ -34,6 +38,14 @@ ChangeManager::ChangeManager()
                                           this, SLOT(onDbChange(QString,QString)));
 }
 
+// Enable management of the birthday calendar
+void ChangeManager::enableBirthdayCalendar()
+{
+    birthdayCalendarEnabled = true;
+
+    onDbChange("CALENDAR", CMulticalendar::MCInstance()->getApplicationName().c_str());
+}
+
 // Start delivering change notifications to the specified client
 void ChangeManager::activateClient(ChangeClient *client)
 {
@@ -79,10 +91,36 @@ void ChangeManager::checkDate()
 // Handle a database change notification from D-Bus
 void ChangeManager::onDbChange(QString details, QString appName)
 {
-    Q_UNUSED(details);
+    // Check if everything is alright with the birthday calendar after each
+    // calendar change.
+    if (birthdayCalendarEnabled && details.contains("CALENDAR")) {
+        CCalendar *calendar = CMulticalendar::MCInstance()->getBirthdayCalendar();
 
-    // Do not react to updates originating from this application, as they are
-    // handled internally.
+        if (birthdayCalendar) {
+            if (calendar) {
+                if (calendar->getCalendarId() == birthdayCalendar->id()) {
+                    // No change
+                    delete calendar;
+                } else {
+                    // Overtaken by another calendar
+                    delete birthdayCalendar;
+                    birthdayCalendar = new BirthdayCalendar(calendar);
+                }
+            } else {
+                // Removed
+                delete birthdayCalendar;
+                birthdayCalendar = NULL;
+            }
+        } else {
+            if (calendar) {
+                // Created
+                birthdayCalendar = new BirthdayCalendar(calendar);
+            }
+        }
+    }
+
+    // Do not react to other updates originating from this application, as they
+    // are handled internally.
     // NOTE: This check will not recognize updates coming from a different
     // instance of this application.
     if (appName != CMulticalendar::MCInstance()->getApplicationName().c_str())
@@ -116,8 +154,7 @@ bool ChangeManager::edit(QWidget *parent, CComponent *component)
             ed = new JournalEditDialog(parent, static_cast<CJournal*>(component));
             break;
         case E_BDAY:
-            // TODO: Editable birthdays?
-            QMaemo5InformationBox::information(parent, QObject::tr("Unable to edit birthdays"));
+            ed = new BirthdayEditDialog(parent, static_cast<CBdayEvent*>(component));
             break;
     }
 
@@ -131,13 +168,13 @@ bool ChangeManager::clone(QWidget *parent, CComponent *component)
 
     switch (component->getType()) {
         case E_EVENT:
-            clone = new CEvent(*static_cast<CEvent*>(component));
+            clone = CWrapper::details(static_cast<CEvent*>(component));
             break;
         case E_TODO:
-            clone = new CTodo(*static_cast<CTodo*>(component));
+            clone = CWrapper::details(static_cast<CTodo*>(component));
             break;
         case E_JOURNAL:
-            clone = new CJournal(*static_cast<CJournal*>(component));
+            clone = CWrapper::details(static_cast<CJournal*>(component));
             break;
         case E_BDAY:
             QMaemo5InformationBox::information(parent, QObject::tr("Unable to edit birthdays"));
@@ -146,7 +183,7 @@ bool ChangeManager::clone(QWidget *parent, CComponent *component)
 
     if (clone) {
         clone->setId(string());
-        return edit(parent, clone);
+        return edit(parent, clone); // The edit dialog will take the ownership of this clone
     } else {
         return false;
     }
@@ -290,6 +327,9 @@ void ChangeManager::modifyComponent(CComponent *component, int calendarId, int &
         case E_JOURNAL:
             mc->modifyJournal(static_cast<CJournal*>(component), calendarId, error);
             break;
+        case E_BDAY:
+            mc->modifyBirthDay(static_cast<CBdayEvent*>(component), error);
+            break;
     }
 }
 
