@@ -1,3 +1,6 @@
+#ifndef DAYWINDOW_H
+#define DAYWINDOW_H
+
 #include "ui_DayWindow.h"
 
 #include <QDate>
@@ -16,6 +19,8 @@ public:
 
     void setDate(QDate date);
 
+    void onChange();
+
 private:
     Ui::DayWindow *ui;
 
@@ -34,3 +39,5 @@ private slots:
     void gotoNextDay();
     void gotoToday();
 };
+
+#endif // DAYWINDOW_H
