@@ -8,6 +8,7 @@
 #include <QShortcut>
 #include <QTimer>
 
+#include <CAlarm.h>
 #include <CEvent.h>
 #include <CRecurrenceRule.h>
 #include "CWrapper.h"
@@ -127,7 +128,7 @@ void EventWindow::reload()
 
     CEvent *event = instance.event;
 
-    ui->summaryInfo->setText(QString::fromUtf8(event->getSummary().c_str()));
+    ui->summaryInfo->setText(CWrapper::summary(event, QDateTime::fromTime_t(instance.stamp).date()));
     ui->locationInfo->setText(QString::fromUtf8(event->getLocation().c_str()));
 
     QString description = QString::fromUtf8(event->getDescription().c_str());
@@ -174,14 +175,14 @@ void EventWindow::reload()
         ui->repeatInfo->setText(repeatText);
     }
 
-    const int secondsBeforeAlarm = event->getAlarmBefore();
-    if (secondsBeforeAlarm < 0) {
-        ui->alarmLabel->hide();
-        ui->alarmInfo->hide();
-    } else {
+    CAlarm *alarm = event->getAlarm();
+    if (alarm) {
         ui->alarmLabel->show();
         ui->alarmInfo->show();
-        ui->alarmInfo->setText(AlarmPickSelector::textForSeconds(secondsBeforeAlarm));
+        ui->alarmInfo->setText(AlarmPickSelector::textForAlarm(*alarm));
+    } else {
+        ui->alarmLabel->hide();
+        ui->alarmInfo->hide();
     }
 
     int error;
@@ -260,3 +261,13 @@ void EventWindow::enableLinks(bool enable)
     ui->locationInfo->enableLinks(enable);
     ui->descriptionInfo->enableLinks(enable);
 }
+
+void EventWindow::contextMenuEvent(QContextMenuEvent *e)
+{
+    QMenu *contextMenu = new QMenu(this);
+    contextMenu->setAttribute(Qt::WA_DeleteOnClose);;
+    contextMenu->addAction(tr("Edit"), this, SLOT(editEvent()));
+    contextMenu->addAction(tr("Clone"), this, SLOT(cloneEvent()));
+    contextMenu->addAction(tr("Delete"), this, SLOT(deleteEvent()));
+    contextMenu->exec(e->globalPos());
+}
